/**
 * Copyright 2008-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.jmx.api;

import javax.management.MBeanRegistration;
import javax.management.modelmbean.ModelMBean;

/**
 * Extends Commons Modeler BaseModelMBean class to allow adding attributes and operations at runtime.
 * @author missonng
 */
public interface IBaseModelMBeanExt extends ModelMBean, MBeanRegistration {

    /**
     * Add an attribute.
     * @param attribute The attribute to add.
     */
    void addAttribute(final IMBeanAttribute attribute);

    /**
     * Remove an attribute.
     * @param attribute The attribute to remove.
     */
    void removeAttribute(final IMBeanAttribute attribute);

    /**
     * Add an operation.
     * @param operation The operation to add.
     */
    void addOperation(final IMBeanOperation operation);

    /**
     * Remove an operation.
     * @param operation The operation to remove.
     */
    void removeOperation(final IMBeanOperation operation);
}
