/**
 * Copyright 2008-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.jmx.api;

/**
 * Allow to register BaseModelMbeanExt with an id.<br>
 * Each attributes and operations are associate with a regexp used to register them on all matching BaseModelMbeanExt.
 * @author missonng
 */
public interface ICommonsModelerExtService {
    /**
     * Start the service.
     */
    void start();

    /**
     * Stop the service.
     */
    void stop();

    /**
     * Get the BaseModelMBeanExt with the given id.
     * @param id The id of the BaseModelMBeanExt to get.
     * @return The BaseModelMBeanExt with the given id.
     */
    IBaseModelMBeanExt getBaseModelMBeanExt(String id);

    /**
     * Register a new BaseModelMBeanExt.
     * @param id The id to register the BaseModelMBeanExt with.
     * @param mbean The BaseModelMBeanExt to register.
     */
    void registerBaseModelMBeanExt(String id, IBaseModelMBeanExt mbean);

    /**
     * Unregister a BaseModelMBeanExt.
     * @param id The id to unregister.
     */
    void unregisterBaseModelMBeanExt(String id);

    /**
     * Register a new attribute.<br>
     * The attribute will automatically be register with each registered BaseModelMBeanExt matching the given regexp.
     * @param attribute The attribute to register.
     * @param regexp The regexp to apply.
     */
    void registerAttribute(IMBeanAttribute attribute, String regexp);

    /**
     * Unregister an attribute.
     * @param attribute The attribute to unregister.
     */
    void unregisterAttribute(IMBeanAttribute attribute);

    /**
     * Register a new operation.<br>
     * The operation will automatically be register with each registered BaseModelMBeanExt matching the given regexp.
     * @param operation The operation to register.
     * @param regexp The regexp to apply.
     */
    void registerOperation(IMBeanOperation operation, String regexp);

    /**
     * Unregister an operation.
     * @param operation The operation to unregister.
     */
    void unregisterOperation(IMBeanOperation operation);
}
